pub struct Thresholds {
pub delta_e: f64,
pub rms_dis: f64,
pub max_dis: f64,
pub max_grad: f64,
pub rms_grad: f64,
}Expand description
Convergence thresholds for MECP optimization.
All five criteria must be satisfied for the optimization to converge. These are the same criteria used in Gaussian optimizations and are considered industry standard.
Units
- Displacement thresholds (
rms,max_dis): Angstrom (Å) - Gradient thresholds (
max_g,rms_g): Hartree/Angstrom (Ha/Å) - Energy threshold (
de): Hartree (Ha)
Default Values
- Energy difference (ΔE): 0.000050 Ha (~0.00136 eV)
- RMS displacement: 0.0025 Å
- Max displacement: 0.004 Å
- Max gradient: 0.001323 Ha/Å
- RMS gradient: 0.000945 Ha/Å
Fields
delta_e: f64Energy difference threshold (ΔE < delta_e) in Hartree.
rms_dis: f64RMS displacement threshold in Angstrom (Å).
max_dis: f64Maximum displacement threshold in Angstrom (Å).
max_grad: f64Maximum gradient threshold in Hartree/Angstrom (Ha/Å).
rms_grad: f64RMS gradient threshold in Hartree/Angstrom (Ha/Å).