pub fn evaluate_constraints(
geometry: &Geometry,
constraints: &[Constraint],
) -> DVector<f64>Expand description
Calculates the current value of each constraint. A positive value means the constraint is violated (e.g., bond is too long).
pub fn evaluate_constraints(
geometry: &Geometry,
constraints: &[Constraint],
) -> DVector<f64>Calculates the current value of each constraint. A positive value means the constraint is violated (e.g., bond is too long).